==> react-common-bootstrap-2.0.47.tgz: package/form/CustomFormFieldSelect.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useMemo } from 'react';
import Select from 'react-select';
import { useFormContext } from './CustomForm';
import { reactSelectStyle } from './react-select-style';
const CustomFormFieldSelect = ({
  options = [],
  value,
  onChange,
  isValid = true,
  noOptionMessage = 'Aucun résultat',
  placeholder = '',
  disabled = false,
  multi = false,
  fieldName = '',
  setFormField = () => {},
  ...props
}, ref) => {
  const {
    displayError
  } = useFormContext();
  const formattedValue = useMemo(() => !multi ? options.find(o => o.value === value) ?? '' : options.filter(o => value.includes(o.value)), [value, options]);
  const handleChangeSelect = obj => {
    if (fieldName != '' && onChange == null) setFormField(fieldName, multi ? obj.map(({
      value
    }) => value) : obj.value);else if (onChange != null) onChange(obj);
  };
  const style = useMemo(() => getComputedStyle(document.body), []);
  return /*#__PURE__*/React.createElement(Select, _extends({
    className: `react-select ${!isValid && displayError ? 'is-invalid' : ''}`,
    value: formattedValue,
    onChange: handleChangeSelect,
    options: options,
    noOptionsMessage: () => noOptionMessage,
    placeholder: placeholder,
    isDisabled: disabled,
    isMulti: multi
  }, reactSelectStyle(displayError, isValid), props));
};
export default CustomFormFieldSelect;

==> react-common-bootstrap-2.0.61.tgz: package/form/CustomFormFieldSelect.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useMemo } from 'react';
import Select from 'react-select';
import { useFormContext } from './CustomForm';
import { reactSelectStyle } from './react-select-style';
const CustomFormFieldSelect = ({
  options = [],
  value,
  onChange,
  isValid = true,
  noOptionMessage = 'Aucun résultat',
  placeholder = '',
  disabled = false,
  multi = false,
  fieldName = '',
  setFormField = () => {},
  ...props
}, ref) => {
  const {
    displayError
  } = useFormContext();
  const allOptions = options.reduce((prev, current) => {
    if (current.options != null) {
      return [...prev, ...current.options];
    }
    return [...prev, current];
  }, []);
  const formattedValue = useMemo(() => !multi ? allOptions.find(o => o.value === value) ?? '' : allOptions.filter(o => value.includes(o.value)), [value, allOptions]);
  const handleChangeSelect = obj => {
    if (fieldName != '' && onChange == null) setFormField(fieldName, multi ? obj.map(({
      value
    }) => value) : obj.value);else if (onChange != null) onChange(obj);
  };
  const style = useMemo(() => getComputedStyle(document.body), []);
  return /*#__PURE__*/React.createElement(Select, _extends({
    className: `react-select ${!isValid && displayError ? 'is-invalid' : ''}`,
    value: formattedValue,
    onChange: handleChangeSelect,
    options: options,
    noOptionsMessage: () => noOptionMessage,
    placeholder: placeholder,
    isDisabled: disabled,
    isMulti: multi
  }, reactSelectStyle(displayError, isValid), props));
};
export default CustomFormFieldSelect;
